@@ -1,3 +1,13 @@
+//! # AVIF image serializer (muxer)
+//!
+//! ## Usage
+//!
+//! 1. Compress pixels using an AV1 encoder, such as [rav1e](//lib.rs/rav1e). [libaom](//lib.rs/libaom-sys) works too.
+//!
+//! 2. Call `avif_serialize::serialize_to_vec(av1_data, None, width, height, 8)`
+//!
+//! See [cavif](https://github.com/kornelski/cavif-rs) for a complete implementation.
+
 mod boxes;
 mod writer;
 
@@ -238,9 +248,9 @@ fn test_roundtrip_parse_mp4() {
     let test_img = b"av12356abc";
     let avif = serialize_to_vec(test_img, None, 10, 20, 8);
 
-    let ctx = mp4parse::read_avif(&mut avif.as_slice()).unwrap();
+    let ctx = mp4parse::read_avif(&mut avif.as_slice(), mp4parse::ParseStrictness::Normal).unwrap();
 
-    assert_eq!(&test_img[..], ctx.primary_item());
+    assert_eq!(&test_img[..], ctx.primary_item_coded_data());
 }
 
 #[test]
@@ -249,10 +259,10 @@ fn test_roundtrip_parse_mp4_alpha() {
     let test_a = b"alpha";
     let avif = serialize_to_vec(test_img, Some(test_a), 10, 20, 8);
 
-    let ctx = mp4parse::read_avif(&mut avif.as_slice()).unwrap();
+    let ctx = mp4parse::read_avif(&mut avif.as_slice(), mp4parse::ParseStrictness::Normal).unwrap();
 
-    assert_eq!(&test_img[..], ctx.primary_item());
-    assert_eq!(&test_a[..], ctx.alpha_item().unwrap());
+    assert_eq!(&test_img[..], ctx.primary_item_coded_data());
+    assert_eq!(&test_a[..], ctx.alpha_item_coded_data());
 }
 
 #[test]
